# Epsilon Example

In these examples we will train Logistic Regression, Ridge Regression, Lasso Regression and Support Vector Machine models on the epsilon dataset, using cuDF dataframe on both `scikit-learn` and `snap-ml-local`. 

The epsilon dataset is from the [PASCAL Large Scale Learning Challenge](http://www.k4all.org/project/large-scale-learning-challenge/). 


## Download the Data

Download and decompress the data from the LIBSVM repository:
```
mkdir data
cd data
wget https://www.csie.ntu.edu.tw/~cjlin/libsvmtools/datasets/binary/epsilon_normalized.bz2
bunzip2 epsilon_normalized.bz2
cd ../
```

## Data Pre-processing
The data is in SvmLight format which is not really appropriate since this dataset is dense. Therefore, we perform 
some pre-processing. 

The entire pre-processing can be run by executing `python $CONDA_PREFIX/pai4sk/local-examples/cudf-examples/preprocess-epsilon.py`

Command to pre-process the data available in specific directory:
`python $CONDA_PREFIX/pai4sk/local-examples/cudf-examples/preprocess-epsilon.py  --data_path path/to/data` directory.

Note: By default the location of `--data_path` is current directory. Parent directory of the directory 'data/' is to be given as parameter to --data_path option.

## Training and Evaluating a Support Vector Machine Model

One can run the entire example by executing `python $CONDA_PREFIX/pai4sk/local-examples/cudf-examples/example-epsilon-cudf-svm.py`

Command to run example using the pre-processed data in specific directory.
`python $CONDA_PREFIX/pai4sk/local-examples/cudf-examples/example-epsilon-cudf-svm.py --data_path path/to/data` directory.

Note: By default the location of `--data_path` is current directory. Parent directory of the directory 'data/' is to be given as parameter to --data_path option.

Command to run example on GPU 0:
python $CONDA_PREFIX/pai4sk/local-examples/cudf-examples/example-epsilon-cudf-svm.py


Command to run example with fit_intercept:
python $CONDA_PREFIX/pai4sk/local-examples/cudf-examples/example-epsilon-cudf-svm.py --fit_intercept





## Training and Evaluating a Logistic Regression Model

One can run the entire example by executing `python $CONDA_PREFIX/pai4sk/local-examples/cudf-examples/example-epsilon-cudf-logistic.py`

Command to run example using the pre-processed data in specific directory.
`python $CONDA_PREFIX/pai4sk/local-examples/cudf-examples/example-epsilon-cudf-logistic.py --data_path path/to/data` directory.

Note: By default the location of `--data_path` is current directory. Parent directory of the directory 'data/' is to be given as parameter to --data_path option.

Command to run example on GPU 0:
python $CONDA_PREFIX/pai4sk/local-examples/cudf-examples/example-epsilon-cudf-logistic.py


Command to run example with fit_intercept:
python $CONDA_PREFIX/pai4sk/local-examples/cudf-examples/example-epsilon-cudf-logistic.py --fit_intercept





## Training and Evaluating a Lasso Regression Model

One can run the entire example by executing `python $CONDA_PREFIX/pai4sk/local-examples/cudf-examples/example-epsilon-cudf-lasso.py`

Command to run example using the pre-processed data in specific directory.
`python $CONDA_PREFIX/pai4sk/local-examples/cudf-examples/example-epsilon-cudf-lasso.py --data_path path/to/data` directory.

Note: By default the location of `--data_path` is current directory. Parent directory of the directory 'data/' is to be given as parameter to --data_path option.

Command to run example on GPU 0:
python $CONDA_PREFIX/pai4sk/local-examples/cudf-examples/example-epsilon-cudf-lasso.py




## Training and Evaluating a Ridge Regression Model

One can run the entire example by executing `python $CONDA_PREFIX/pai4sk/local-examples/cudf-examples/example-epsilon-cudf-ridge.py`

Command to run example using the pre-processed data in specific directory.
`python $CONDA_PREFIX/pai4sk/local-examples/cudf-examples/example-epsilon-cudf-ridge.py --data_path path/to/data` directory.

Note: By default the location of `--data_path` is current directory. Parent directory of the directory 'data/' is to be given as parameter to --data_path option.

Command to run example on GPU 0:
python $CONDA_PREFIX/pai4sk/local-examples/cudf-examples/example-epsilon-cudf-ridge.py


Note: pai4sk currently supports only C-contiguous ndarray and DeviceNDArray as input.

&copy; Copyright IBM Corporation 2019
