# Mnist Example

In this example we will train a Logistic Regression model on the mnist8m dataset, using both `scikit-learn` and `snap-ml-local`. 
The dataset is a multi-class classification problem.

The mnist8m dataset is from the [LIBSVM repository](https://www.csie.ntu.edu.tw/~cjlin/libsvmtools/datasets/multiclass).

## Download the Data

Download and decompress the data from the LIBSVM repository:
```
mkdir data
cd data
wget https://www.csie.ntu.edu.tw/~cjlin/libsvmtools/datasets/multiclass/mnist8m.scale.bz2
bunzip2 mnist8m.scale.bz2
cd ../
```

## Data Pre-processing
The data is in SvmLight format. We start by performing some pre-processing.

The entire pre-processing can be run by executing `python $CONDA_PREFIX/pai4sk/local-examples/example-mnist8m/preprocess-mnist8m.py`

Command to pre-process the data available in specific directory:
`python $CONDA_PREFIX/pai4sk/local-examples/example-mnist8m/preprocess-mnist8m.py --data_path path/to/data` directory.

Note: By default the location of `--data_path` is current directory. Parent directory of the directory 'data/' is to be given as parameter to --data_path option.

## Training and Evaluating a Logistic Regression Model
One can run the entire example by executing `python $CONDA_PREFIX/pai4sk/local-examples/example-mnist8m/example-mnist8m.py`

Command to run example using the pre-processed data in specific directory.
`python $CONDA_PREFIX/pai4sk/local-examples/example-mnist8m/example-mnist8m.py --data_path path/to/data` directory.

Note: By default the location of `--data_path` is current directory. Parent directory of the directory 'data/' is to be given as parameter to --data_path option.

Command to run example on GPU 0:
python $CONDA_PREFIX/pai4sk/local-examples/example-mnist8m/example-mnist8m.py --use_gpu

Command to run example on specified GPUs:
python $CONDA_PREFIX/pai4sk/local-examples/example-mnist8m/example-mnist8m.py --use_gpu --device_ids 1 2

Command to run example with fit_intercept: 
python $CONDA_PREFIX/pai4sk/local-examples/example-mnist8m/example-mnist8m.py --use_gpu --fit_intercept

Command to collect training information: 
```
python $CONDA_PREFIX/pai4sk/local-examples/example-mnist8m/example-mnist8m.py --use_gpu --return_training_history=full

python $CONDA_PREFIX/pai4sk/local-examples/example-mnist8m/example-mnist8m.py --use_gpu --return_training_history=summary
```

One should see the following output on P9+V100 System (--use_gpu --device_ids 0):
```
Data load time (s): 26.46
[pai4sk] Training time (s):  63.90
[pai4sk] Accuracy:   0.8624
[pai4sk.lmodel] Training time (s):  65.68
[pai4sk.lmodel] Accuracy:   0.8624
[sklearn] Training time (s):  552.17
[sklearn] Accuracy:   0.8622
```

Times will vary depending on the system architecture. 

Note: By default the training will run on CPU. 
With --use_gpu option, default device_ids list contains only GPU 0 for pai4sk and all the available GPUs for pai4sk.lmodel.

&copy; Copyright IBM Corporation 2018, 2019
