# *****************************************************************
#
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2018. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# *****************************************************************

from scipy import sparse

# Load the data
import time
import numpy as np
import argparse

from pai4sk.metrics import accuracy_score

defaultPath = "."
CLI=argparse.ArgumentParser()

CLI.add_argument(
    "--skip_sklearn",
    action = 'store_true',
    default=False
)
CLI.add_argument(
    "--data_path",
    type=str,
    default=defaultPath
)

args = CLI.parse_args()

t0 = time.time()
X_train = np.load(args.data_path + "/data/SUSY.X_train.npy")
X_test  = np.load(args.data_path + "/data/SUSY.X_test.npy")
y_train = np.load(args.data_path + "/data/SUSY.y_train.npy")
y_test  = np.load(args.data_path + "/data/SUSY.y_test.npy")
print("Data load time (s):  {0:.2f}".format(time.time()-t0))

max_depth = None
n_ex = X_train.shape[0]

# Import snap DecisionTreeClassifier from pai4sk module directly
from pai4sk import DecisionTreeClassifier as SnapTree
dt = SnapTree(random_state=0, verbose=False, max_depth=max_depth)

# Training time
t0 = time.time()
dt.fit(X_train[0:n_ex], y_train[0:n_ex])
print("[snap.defaults] Training time (s):  {0:.2f}".format(time.time()-t0))
       
# Inference
pred_test = dt.predict(X_test)
acc_snap = accuracy_score(y_test, pred_test)
print("[snap.defaults] Accuracy score:   {0:.4f}".format(acc_snap))

if not args.skip_sklearn:    
    # Import sklearn's DecisionTreeClassifier from pai4sk module directly
    from pai4sk.tree import DecisionTreeClassifier as SklearnTree
    dt = SklearnTree(random_state=0, max_depth=max_depth)

    # Training time
    t0 = time.time()
    dt.fit(X_train[0:n_ex], y_train[0:n_ex])
    print("[sklearn.defaults] Training time (s):  {0:.2f}".format(time.time()-t0))

    # Inference
    pred_test = dt.predict(X_test)

    # Evaluate accuracy_score on test set
    acc_sklearn = accuracy_score(y_test, pred_test)
    print("[sklearn.defaults] Accuracy score:   {0:.4f}".format(acc_sklearn))


max_depth = 6

# pai4sk snap decision tree with histograms
dt = SnapTree(random_state=0, verbose=False, max_depth=max_depth, hist_type='Auto', hist_nbins=64)

# Training time
t0 = time.time()
dt.fit(X_train[0:n_ex], y_train[0:n_ex])
print("[snap.histogram.depth6] Training time (s):  {0:.2f}".format(time.time()-t0))

# Inference
pred_test = dt.predict(X_test)
acc_snap = accuracy_score(y_test, pred_test)
print("[snap.histogram.depth6] Accuracy score:   {0:.4f}".format(acc_snap))

if not args.skip_sklearn:
    # Import sklearn's DecisionTreeClassifier from pai4sk module directly
    from pai4sk.tree import DecisionTreeClassifier as SklearnTree
    dt = SklearnTree(random_state=0, max_depth=max_depth)

    # Training time
    t0 = time.time()
    dt.fit(X_train[0:n_ex], y_train[0:n_ex])
    print("[sklearn.depth6] Training time (s):  {0:.2f}".format(time.time()-t0))

    # Inference
    pred_test = dt.predict(X_test)

    # Evaluate accuracy_score on test set
    acc_sklearn = accuracy_score(y_test, pred_test)
    print("[sklearn.depth6] Accuracy score:   {0:.4f}".format(acc_sklearn))

